]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
Disentangle the MANDOCERR_CHILD message, which reported three
[mandoc.git] / mandoc.h
index f61d28f01d57c582bd2e33ba4eff12213ed216a3..f0005e61023ef4f7feaad204dc3ef1cbd44531e1 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,4 +1,4 @@
-/*     $Id: mandoc.h,v 1.126 2014/07/02 03:48:07 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.129 2014/07/02 13:10:45 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
@@ -72,14 +72,16 @@ enum        mandocerr {
 
        /* related to macros and nesting */
        MANDOCERR_MACRO_OBS, /* obsolete macro: macro */
-       MANDOCERR_IGNPAR, /* skipping paragraph macro */
-       MANDOCERR_MOVEPAR, /* moving paragraph macro out of list */
-       MANDOCERR_IGNNS, /* skipping no-space macro */
-       MANDOCERR_SCOPENEST, /* blocks badly nested */
-       MANDOCERR_CHILD, /* child violates parent syntax */
-       MANDOCERR_NESTEDDISP, /* nested displays are not portable */
-       MANDOCERR_SCOPEREP, /* already in literal mode */
-       MANDOCERR_LINESCOPE, /* line scope broken */
+       MANDOCERR_PAR_SKIP, /* skipping paragraph macro: macro ... */
+       MANDOCERR_PAR_MOVE, /* moving paragraph macro out of list: macro */
+       MANDOCERR_NS_SKIP, /* skipping no-space macro */
+       MANDOCERR_BLOCK_NEST, /* blocks badly nested: macro ... */
+       MANDOCERR_BD_NEST, /* nested displays are not portable: macro ... */
+       MANDOCERR_BL_MOVE, /* moving content out of list: macro */
+       MANDOCERR_VT_CHILD, /* .Vt block has child macro: macro */
+       MANDOCERR_FI_SKIP, /* fill mode already enabled, skipping .fi */
+       MANDOCERR_NF_SKIP, /* fill mode already disabled, skipping .nf */
+       MANDOCERR_LINESCOPE, /* line scope broken: macro breaks macro */
 
        /* related to missing macro arguments */
        MANDOCERR_MACROEMPTY, /* skipping empty macro */
@@ -88,7 +90,6 @@ enum  mandocerr {
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
        MANDOCERR_FONTTYPE, /* missing font type */
-       MANDOCERR_WNOSCOPE, /* skipping end of block that is not open */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
@@ -136,6 +137,7 @@ enum        mandocerr {
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
+       MANDOCERR_RS_SKIP, /* skipping invalid content in .Rs block: macro */
        MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */